==> blogmate-0.1.0.tgz: package/lib/helpers.js <==
(function() {
  var mark_bold, mark_bold_italic, mark_italic, replace_links, replace_scripts;
  replace_scripts = function(l) {
    var matches, script_regex, scripts;
    script_regex = /\[script\]\(([\w|#!:.?+=&%@!\-\/]*)\)/gi;
    matches = l.match(script_regex);
    scripts = [];
    if (matches) {
      matches.each(function() {
        var m;
        m = script_regex.exec(l);
        return scripts.push({
          short_form: m[0],
          src: m[1]
        });
      });
    }
    scripts.each(function(s) {
      return l = l.replace(s.short_form, "<script src=\"" + s.src + "\" type=\"text/javascrip\"></script>");
    });
    return l;
  };
  replace_links = function(l) {
    var links, links_regex, matches;
    links_regex = /\[([\w|\s|#!:.?+=&%@!\-\/]*)\]\(([\w|#!:.?+=&%@!\-\/]*) "([\w|\s|#!:.?+=&%@!\-\/]*)"\)/gi;
    matches = l.match(links_regex);
    links = [];
    if (matches) {
      matches.each(function() {
        var m;
        m = links_regex.exec(l);
        return links.push({
          short_form: m[0],
          href: m[2],
          title: m[3],
          element: m[1]
        });
      });
    }
    links.each(function(a) {
      return l = l.replace(a.short_form, "<a href=\"" + a.href + "\" title=\"" + a.title + "\">" + a.element + "</a>");
    });
    return l;
  };
  mark_bold_italic = function(l) {
    var i, tokens, _fn, _ref;
    tokens = l.match(/\*\*\*/g);
    if (tokens) {
      _fn = function() {
        var tag;
        tag = i % 2 ? '<b><i>' : '</i></b>';
        return l = l.replace('***', tag, 1);
      };
      for (i = 1, _ref = tokens.length; 1 <= _ref ? i <= _ref : i >= _ref; 1 <= _ref ? i++ : i--) {
        _fn();
      }
    }
    return l;
  };
  mark_bold = function(l) {
    var i, tokens, _fn, _ref;
    tokens = l.match(/\*\*/g);
    if (tokens) {
      _fn = function() {
        var tag;
        tag = i % 2 ? '<b>' : '</b>';
        return l = l.replace('**', tag, 1);
      };
      for (i = 1, _ref = tokens.length; 1 <= _ref ? i <= _ref : i >= _ref; 1 <= _ref ? i++ : i--) {
        _fn();
      }
    }
    return l;
  };
  mark_italic = function(l) {
    var i, tokens, _fn, _ref;
    tokens = l.match(/\*/g);
    if (tokens) {
      _fn = function() {
        var tag;
        tag = i % 2 ? '<i>' : '</i>';
        return l = l.replace('*', tag, 1);
      };
      for (i = 1, _ref = tokens.length; 1 <= _ref ? i <= _ref : i >= _ref; 1 <= _ref ? i++ : i--) {
        _fn();
      }
    }
    return l;
  };
  module.exports = {
    html: function(text) {
      var html, lines;
      lines = text.split('\n');
      html = "";
      lines.each(function(l) {
        if (l !== "") {
          l = mark_bold_italic(l);
          l = mark_bold(l);
          l = mark_italic(l);
          l = replace_links(l);
          l = replace_scripts(l);
          return html += "<p>" + l + "</p>";
        }
      });
      return html;
    },
    disqus: function(conf, post) {
      return "<div id=\"disqus_thread\"></div>\n<script type=\"text/javascript\">\n  var disqus_shortname = '" + conf.disqus_name + "';\n  var disqus_identifier = '" + post.slug + "';\n  var disqus_url = '" + conf.website_url + "/posts/" + post.slug + "';\n\n  /* * * DON'T EDIT BELOW THIS LINE * * */\n  (function() {\n    var dsq = document.createElement('script'); dsq.type = 'text/javascript'; dsq.async = true;\n    dsq.src = 'http://' + disqus_shortname + '.disqus.com/embed.js';\n    (document.getElementsByTagName('head')[0] || document.getElementsByTagName('body')[0]).appendChild(dsq);\n  })();\n</script>";
    }
  };
}).call(this);

==> blogmate-0.1.4.tgz: package/lib/helpers.js <==
(function() {
  var mark_bold, mark_bold_italic, mark_italic, replace_links, replace_scripts;
  replace_scripts = function(l) {
    var matches, script_regex, scripts;
    script_regex = /\[script\]\(([\w|#!:.?+=&%@!\-\/]*)\)/gi;
    matches = l.match(script_regex);
    scripts = [];
    if (matches) {
      matches.each(function() {
        var m;
        m = script_regex.exec(l);
        return scripts.push({
          short_form: m[0],
          src: m[1]
        });
      });
    }
    scripts.each(function(s) {
      return l = l.replace(s.short_form, "<script src=\"" + s.src + "\" type=\"text/javascript\"></script>");
    });
    return l;
  };
  replace_links = function(l) {
    var links, links_regex, matches;
    links_regex = /\[([\w|\s|#!:.?+=&%@!\-\/]*)\]\(([\w|#!:.?+=&%@!\-\/]*) "([\w|\s|#!:.?+=&%@!\-\/]*)"\)/gi;
    matches = l.match(links_regex);
    links = [];
    if (matches) {
      matches.each(function() {
        var m;
        m = links_regex.exec(l);
        return links.push({
          short_form: m[0],
          href: m[2],
          title: m[3],
          element: m[1]
        });
      });
    }
    links.each(function(a) {
      return l = l.replace(a.short_form, "<a href=\"" + a.href + "\" title=\"" + a.title + "\">" + a.element + "</a>");
    });
    return l;
  };
  mark_bold_italic = function(l) {
    var i, tokens, _fn, _ref;
    tokens = l.match(/\*\*\*/g);
    if (tokens) {
      _fn = function() {
        var tag;
        tag = i % 2 ? '<b><i>' : '</i></b>';
        return l = l.replace('***', tag, 1);
      };
      for (i = 1, _ref = tokens.length; 1 <= _ref ? i <= _ref : i >= _ref; 1 <= _ref ? i++ : i--) {
        _fn();
      }
    }
    return l;
  };
  mark_bold = function(l) {
    var i, tokens, _fn, _ref;
    tokens = l.match(/\*\*/g);
    if (tokens) {
      _fn = function() {
        var tag;
        tag = i % 2 ? '<b>' : '</b>';
        return l = l.replace('**', tag, 1);
      };
      for (i = 1, _ref = tokens.length; 1 <= _ref ? i <= _ref : i >= _ref; 1 <= _ref ? i++ : i--) {
        _fn();
      }
    }
    return l;
  };
  mark_italic = function(l) {
    var i, tokens, _fn, _ref;
    tokens = l.match(/\*/g);
    if (tokens) {
      _fn = function() {
        var tag;
        tag = i % 2 ? '<i>' : '</i>';
        return l = l.replace('*', tag, 1);
      };
      for (i = 1, _ref = tokens.length; 1 <= _ref ? i <= _ref : i >= _ref; 1 <= _ref ? i++ : i--) {
        _fn();
      }
    }
    return l;
  };
  module.exports = {
    html: function(text) {
      var html, lines;
      lines = text.split('\n');
      html = "";
      lines.each(function(l) {
        if (l !== "") {
          l = mark_bold_italic(l);
          l = mark_bold(l);
          l = mark_italic(l);
          l = replace_links(l);
          l = replace_scripts(l);
          return html += "<p>" + l + "</p>";
        }
      });
      return html;
    },
    disqus: function(conf, post) {
      return "<div id=\"disqus_thread\"></div>\n<script type=\"text/javascript\">\n  var disqus_shortname = '" + conf.disqus_name + "';\n  var disqus_identifier = '" + post.slug + "';\n  var disqus_url = '" + conf.website_url + "/posts/" + post.slug + "';\n\n  /* * * DON'T EDIT BELOW THIS LINE * * */\n  (function() {\n    var dsq = document.createElement('script'); dsq.type = 'text/javascript'; dsq.async = true;\n    dsq.src = 'http://' + disqus_shortname + '.disqus.com/embed.js';\n    (document.getElementsByTagName('head')[0] || document.getElementsByTagName('body')[0]).appendChild(dsq);\n  })();\n</script>";
    }
  };
}).call(this);
